/*
 *  Copyright (C) 2002 Steve Harris, ECS, University of Southampton
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

#ifndef RDFSQL_DATATYPES_H
#define RDFSQL_DATATYPES_H

#include <glib.h>

/* Standard RDF URIs */

#define RDF_NAMESPACE  "http://www.w3.org/1999/02/22-rdf-syntax-ns#"
#define RDFS_NAMESPACE "http://www.w3.org/2000/01/rdf-schema#"
#define OWL_NAMESPACE "http://www.w3.org/2002/07/owl#"

#define RDF_TYPE     RDF_NAMESPACE "type"
#define RDF_PROPERTY RDF_NAMESPACE "Property"
#define OWL_OBJPROPERTY OWL_NAMESPACE "ObjectProperty"
#define OWL_DATPROPERTY OWL_NAMESPACE "DatatypeProperty"

#define RDFS_CLASS        RDFS_NAMESPACE "Class"
#define OWL_CLASS         OWL_NAMESPACE "Class"
#define RDFS_RESOURCE     RDFS_NAMESPACE "Resource"
#define RDFS_SUBCLASS     RDFS_NAMESPACE "subClassOf"
#define RDFS_SUBPROPERTY  RDFS_NAMESPACE "subPropertyOf"
#define RDFS_DOMAIN       RDFS_NAMESPACE "domain"
#define RDFS_RANGE        RDFS_NAMESPACE "range"
#define RDFS_LABEL    RDFS_NAMESPACE "label"

/* Error codes */
#define RS_SUCCESS   0
#define RS_BAD_TYPE  1
#define RS_BAD_SQL   2
#define RS_ALLREADY  3

typedef struct {
	void *db;
	guint64	model;
} RDFSQL;

typedef enum {
	ObjAny = -1,
	ObjURI = 0,
	ObjLiteral = 1
} rs_obj_type;

/* supported RDF syntaxes */
typedef enum {
	RS_AUTO = 0,
	RS_XML,
	RS_NTRIPLES,
	RS_TURTLE
} rs_syntax;

/* rs_triple: transparent struct containing information about a triple received
 * from the databse. Not user modifiable.
 */
typedef struct {
	char *subject;
	char *predicate;
	char *object;
	int literal;
} rs_triple;

/* rs_result: opaque struct containing information need to traverse result
 * sets. Not user modifiable.
 */

typedef struct {
	void *db_res;
	rs_triple t;
	int subj_idx;
	int pred_idx;
	int obj_idx;
	int lit_idx;
} rs_result;

/* rs_raw_triple: a data type representing the hased values of a triple */

typedef struct {
	guint64 subj;
	guint64 pred;
	guint64 obj;
} rs_raw_triple;

#endif
